@@ -43,7 +43,6 @@
 @b nodeletcpp is a tool for loading/unloading nodelets to/from a Nodelet manager.
 **/
 #include <signal.h>
-#include <uuid/uuid.h>
 
 #include <ros/ros.h>
 #include <ros/xmlrpc_manager.h>
@@ -53,13 +52,29 @@
 #include "nodelet/NodeletLoad.h"
 #include "nodelet/NodeletUnload.h"
 
+#ifndef _WIN32
+# include <uuid/uuid.h>
+#else
+# include <rpc.h>
+#endif
+
 std::string genId()
 {
+#ifndef _WIN32
   uuid_t uuid;
   uuid_generate_random(uuid);
   char uuid_str[40];
   uuid_unparse(uuid, uuid_str);
   return std::string(uuid_str);
+#else
+  UUID uuid;
+  UuidCreate(&uuid);
+  RPC_CSTR str;
+  UuidToStringA(&uuid, &str);
+  std::string return_string(reinterpret_cast<char *>(str));
+  RpcStringFreeA(&str);
+  return return_string;
+#endif
 }
 
 class NodeletArgumentParsing
@@ -72,7 +87,7 @@ class NodeletArgumentParsing
     std::string manager_;
     std::vector<std::string> local_args_;
     bool is_bond_enabled_;
-  
+
   public:
     //NodeletArgumentParsing() { };
     bool
@@ -106,15 +121,16 @@ class NodeletArgumentParsing
 
       else if (command_ == "unload" && non_ros_args.size() > 3)
       {
-	name_    = non_ros_args[2];
-	manager_ = non_ros_args[3];
-	used_args = 4;
+        type_    = "nodelet_unloader";
+        name_    = non_ros_args[2];
+        manager_ = non_ros_args[3];
+        used_args = 4;
       }
       else if (command_ == "standalone" && non_ros_args.size() > 2)
       {
-	type_ = non_ros_args[2];
-	printf("type is %s\n", type_.c_str());
-	used_args = 3;
+        type_ = non_ros_args[2];
+        printf("type is %s\n", type_.c_str());
+        used_args = 3;
       }
 
       if (command_ == "manager")
@@ -241,14 +257,14 @@ void print_usage(int argc, char** argv)
   printf("\nnodelet usage:\n");
   printf("nodelet load pkg/Type manager [--no-bond]  - Launch a nodelet of type pkg/Type on manager manager\n");
   printf("nodelet standalone pkg/Type   - Launch a nodelet of type pkg/Type in a standalone node\n");
-  printf("nodelet unload name manager   - Unload a nodelet a nodelet by name from manager\n");
+  printf("nodelet unload name manager   - Unload a nodelet by name from manager\n");
   printf("nodelet manager               - Launch a nodelet manager node\n");
 
 };
 
 sig_atomic_t volatile request_shutdown = 0;
 
-void nodeletLoaderSigIntHandler(int sig)
+void nodeletLoaderSigIntHandler(int)
 {
   request_shutdown = 1;
 }
@@ -327,7 +343,7 @@ int
     signal(SIGINT, nodeletLoaderSigIntHandler);
     ros::XMLRPCManager::instance()->unbind("shutdown");
     ros::XMLRPCManager::instance()->bind("shutdown", shutdownCallback);
-    
+
     if (arg_parser.isBondEnabled())
       bond.start();
     // Spin our own loop
@@ -340,7 +356,11 @@ int
         ROS_INFO("Bond broken, exiting");
         goto shutdown;
       }
+#ifndef _WIN32
       usleep(100000);
+#else
+      Sleep(100);
+#endif
     }
     // Attempt to unload the nodelet before shutting down ROS
     ni.unloadNodelet(name, manager);
